#include <stdexcept>
#include "OpenModelicaScriptingAPIQt.h"

OMCInterface::OMCInterface(threadData_t *td, void *symbolTable)
  : threadData(td), st(symbolTable)
{
}
OMCInterface::generateScriptingAPI_res OMCInterface::generateScriptingAPI(QString cl, QString name)
{
  QByteArray cl_utf8 = cl.toUtf8();
  QByteArray name_utf8 = name.toUtf8();
  generateScriptingAPI_res result;
  void *out2_mm = NULL;
  void *out3_mm = NULL;
  void *out4_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("generateScriptingAPI("+cl+"," +name+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_generateScriptingAPI(threadData, st, mmc_mk_scon(cl_utf8.data()), mmc_mk_scon(name_utf8.data()), &result.success, &out2_mm, &out3_mm, &out4_mm);
  result.moFile = QString::fromUtf8(MMC_STRINGDATA(out2_mm));
  result.qtFile = QString::fromUtf8(MMC_STRINGDATA(out3_mm));
  result.qtHeader = QString::fromUtf8(MMC_STRINGDATA(out4_mm));
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("generateScriptingAPI failed");)
  
  return result;
}
OMCInterface::getClassInformation_res OMCInterface::getClassInformation(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  getClassInformation_res result;
  void *out1_mm = NULL;
  void *out2_mm = NULL;
  void *out6_mm = NULL;
  void *out12_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getClassInformation("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getClassInformation(threadData, st, mmc_mk_scon(cl_utf8.data()), &out1_mm, &out2_mm, &result.partialPrefix, &result.finalPrefix, &result.encapsulatedPrefix, &out6_mm, &result.fileReadOnly, &result.lineNumberStart, &result.columnNumberStart, &result.lineNumberEnd, &result.columnNumberEnd, &out12_mm);
  result.restriction = QString::fromUtf8(MMC_STRINGDATA(out1_mm));
  result.comment = QString::fromUtf8(MMC_STRINGDATA(out2_mm));
  result.fileName = QString::fromUtf8(MMC_STRINGDATA(out6_mm));
  result.dimensions.clear();
  while (!listEmpty(out12_mm)) {
    QString out12_elt;
    out12_elt = MMC_STRINGDATA(MMC_CAR(out12_mm));
    result.dimensions.push_back(out12_elt);
    out12_mm = MMC_CDR(out12_mm);
  }
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getClassInformation failed");)
  
  return result;
}
QString OMCInterface::sortStrings(QList<QString > arr)
{
  void *arr_lst = mmc_mk_nil();
  for (int arr_i = arr.size()-1; arr_i>=0; arr_i--) {
    QString arr_elt = arr[arr_i];
    QByteArray arr_elt_utf8 = arr_elt.toUtf8();
    arr_lst = mmc_mk_cons(mmc_mk_scon(arr_elt_utf8.data()), arr_lst);
  }
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("sortStrings("+QString("### Handle array arguments ###")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_sortStrings(threadData, st, arr_lst, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("sortStrings failed");)
  
  return result;
}
modelica_boolean OMCInterface::checkInterfaceOfPackages(QString cl, QList<QList<QString > > dependencyMatrix)
{
  QByteArray cl_utf8 = cl.toUtf8();
  void *dependencyMatrix_lst = mmc_mk_nil();
  for (int dependencyMatrix_i = dependencyMatrix.size()-1; dependencyMatrix_i>=0; dependencyMatrix_i--) {
    QList<QString > dependencyMatrix_elt = dependencyMatrix[dependencyMatrix_i];
    void *dependencyMatrix_elt_lst = mmc_mk_nil();
    for (int dependencyMatrix_elt_i = dependencyMatrix_elt.size()-1; dependencyMatrix_elt_i>=0; dependencyMatrix_elt_i--) {
      QString dependencyMatrix_elt_elt = dependencyMatrix_elt[dependencyMatrix_elt_i];
      QByteArray dependencyMatrix_elt_elt_utf8 = dependencyMatrix_elt_elt.toUtf8();
      dependencyMatrix_elt_lst = mmc_mk_cons(mmc_mk_scon(dependencyMatrix_elt_elt_utf8.data()), dependencyMatrix_elt_lst);
    }
    dependencyMatrix_lst = mmc_mk_cons(dependencyMatrix_elt_lst, dependencyMatrix_lst);
  }
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("checkInterfaceOfPackages("+cl+"," +QString("### Handle array arguments ###")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_checkInterfaceOfPackages(threadData, st, mmc_mk_scon(cl_utf8.data()), dependencyMatrix_lst, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("checkInterfaceOfPackages failed");)
  
  return result;
}
modelica_boolean OMCInterface::GC_expand_hp(modelica_integer size)
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("GC__expand__hp("+QString::number(size)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_GC__expand__hp(threadData, st, size, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("GC__expand__hp failed");)
  
  return result;
}
void OMCInterface::GC_gcollect_and_unmap()
{
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("GC__gcollect__and__unmap("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_GC__gcollect__and__unmap(threadData, st);
  QString responseLog;
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("GC__gcollect__and__unmap failed");)
  
}
modelica_real OMCInterface::getMemorySize()
{
  modelica_real result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getMemorySize("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getMemorySize(threadData, st, &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getMemorySize failed");)
  
  return result;
}
void OMCInterface::threadWorkFailed()
{
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("threadWorkFailed("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_threadWorkFailed(threadData, st);
  QString responseLog;
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("threadWorkFailed failed");)
  
}
void OMCInterface::exit(modelica_integer status)
{
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("exit("+QString::number(status)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_exit(threadData, st, status);
  QString responseLog;
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("exit failed");)
  
}
QList<modelica_boolean > OMCInterface::runScriptParallel(QList<QString > scripts, modelica_integer numThreads, modelica_boolean useThreads)
{
  void *scripts_lst = mmc_mk_nil();
  for (int scripts_i = scripts.size()-1; scripts_i>=0; scripts_i--) {
    QString scripts_elt = scripts[scripts_i];
    QByteArray scripts_elt_utf8 = scripts_elt.toUtf8();
    scripts_lst = mmc_mk_cons(mmc_mk_scon(scripts_elt_utf8.data()), scripts_lst);
  }
  QList<modelica_boolean > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("runScriptParallel("+QString("### Handle array arguments ###")+"," +QString::number(numThreads)+"," +QString(useThreads ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_runScriptParallel(threadData, st, scripts_lst, numThreads, useThreads, &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    modelica_boolean result_elt;
    result_elt = mmc_unbox_boolean(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(modelica_boolean result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(result_elt ? "true" : "false");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("runScriptParallel failed");)
  
  return result;
}
modelica_integer OMCInterface::numProcessors()
{
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("numProcessors("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_numProcessors(threadData, st, &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("numProcessors failed");)
  
  return result;
}
void OMCInterface::generateEntryPoint(QString fileName, QString entryPoint, QString url)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QByteArray entryPoint_utf8 = entryPoint.toUtf8();
  QByteArray url_utf8 = url.toUtf8();
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("generateEntryPoint("+fileName+"," +entryPoint+"," +url+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_generateEntryPoint(threadData, st, mmc_mk_scon(fileName_utf8.data()), mmc_mk_scon(entryPoint_utf8.data()), mmc_mk_scon(url_utf8.data()));
  QString responseLog;
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("generateEntryPoint failed");)
  
}
QString OMCInterface::getDerivedClassModifierValue(QString className, QString modifierName)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray modifierName_utf8 = modifierName.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getDerivedClassModifierValue("+className+"," +modifierName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getDerivedClassModifierValue(threadData, st, mmc_mk_scon(className_utf8.data()), mmc_mk_scon(modifierName_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getDerivedClassModifierValue failed");)
  
  return result;
}
QList<QString > OMCInterface::getDerivedClassModifierNames(QString className)
{
  QByteArray className_utf8 = className.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getDerivedClassModifierNames("+className+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getDerivedClassModifierNames(threadData, st, mmc_mk_scon(className_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getDerivedClassModifierNames failed");)
  
  return result;
}
QList<QList<QString > > OMCInterface::getUses(QString pack)
{
  QByteArray pack_utf8 = pack.toUtf8();
  QList<QList<QString > > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getUses("+pack+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getUses(threadData, st, mmc_mk_scon(pack_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QList<QString > result_elt;
    result_elt.clear();
    while (!listEmpty(MMC_CAR(result_mm))) {
      QString result_elt_elt;
      result_elt_elt = MMC_STRINGDATA(MMC_CAR(MMC_CAR(result_mm)));
      result_elt.push_back(result_elt_elt);
      MMC_CAR(result_mm) = MMC_CDR(MMC_CAR(result_mm));
    }
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QList<QString > result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("{");
    int result_elt_i = 0;
    foreach(QString result_elt_elt, result_elt) {
      if (result_elt_i) {
        responseLog.append(",");
      }
      responseLog.append("\"" + result_elt_elt + "\"");
      result_elt_i++;
    }
    responseLog.append("}");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getUses failed");)
  
  return result;
}
QList<QString > OMCInterface::getAvailableLibraries()
{
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getAvailableLibraries("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getAvailableLibraries(threadData, st, &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getAvailableLibraries failed");)
  
  return result;
}
QList<QString > OMCInterface::searchClassNames(QString searchText, modelica_boolean findInText)
{
  QByteArray searchText_utf8 = searchText.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("searchClassNames("+searchText+"," +QString(findInText ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_searchClassNames(threadData, st, mmc_mk_scon(searchText_utf8.data()), findInText, &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(result_elt);
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("searchClassNames failed");)
  
  return result;
}
modelica_boolean OMCInterface::extendsFrom(QString className, QString baseClassName)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray baseClassName_utf8 = baseClassName.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("extendsFrom("+className+"," +baseClassName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_extendsFrom(threadData, st, mmc_mk_scon(className_utf8.data()), mmc_mk_scon(baseClassName_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("extendsFrom failed");)
  
  return result;
}
modelica_boolean OMCInterface::getBooleanClassAnnotation(QString className, QString annotationName)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray annotationName_utf8 = annotationName.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getBooleanClassAnnotation("+className+"," +annotationName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getBooleanClassAnnotation(threadData, st, mmc_mk_scon(className_utf8.data()), mmc_mk_scon(annotationName_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getBooleanClassAnnotation failed");)
  
  return result;
}
modelica_boolean OMCInterface::classAnnotationExists(QString className, QString annotationName)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray annotationName_utf8 = annotationName.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("classAnnotationExists("+className+"," +annotationName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_classAnnotationExists(threadData, st, mmc_mk_scon(className_utf8.data()), mmc_mk_scon(annotationName_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("classAnnotationExists failed");)
  
  return result;
}
OMCInterface::getSimulationOptions_res OMCInterface::getSimulationOptions(QString name, modelica_real defaultStartTime, modelica_real defaultStopTime, modelica_real defaultTolerance, modelica_integer defaultNumberOfIntervals, modelica_real defaultInterval)
{
  QByteArray name_utf8 = name.toUtf8();
  getSimulationOptions_res result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getSimulationOptions("+name+"," +QString::number(defaultStartTime)+"," +QString::number(defaultStopTime)+"," +QString::number(defaultTolerance)+"," +QString::number(defaultNumberOfIntervals)+"," +QString::number(defaultInterval)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getSimulationOptions(threadData, st, mmc_mk_scon(name_utf8.data()), defaultStartTime, defaultStopTime, defaultTolerance, defaultNumberOfIntervals, defaultInterval, &result.startTime, &result.stopTime, &result.tolerance, &result.numberOfIntervals, &result.interval);
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getSimulationOptions failed");)
  
  return result;
}
modelica_boolean OMCInterface::isExperiment(QString name)
{
  QByteArray name_utf8 = name.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isExperiment("+name+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isExperiment(threadData, st, mmc_mk_scon(name_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isExperiment failed");)
  
  return result;
}
QString OMCInterface::getBuiltinType(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getBuiltinType("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getBuiltinType(threadData, st, mmc_mk_scon(cl_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getBuiltinType failed");)
  
  return result;
}
modelica_boolean OMCInterface::isProtectedClass(QString cl, QString c2)
{
  QByteArray cl_utf8 = cl.toUtf8();
  QByteArray c2_utf8 = c2.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isProtectedClass("+cl+"," +c2+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isProtectedClass(threadData, st, mmc_mk_scon(cl_utf8.data()), mmc_mk_scon(c2_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isProtectedClass failed");)
  
  return result;
}
modelica_boolean OMCInterface::isOperatorFunction(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isOperatorFunction("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isOperatorFunction(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isOperatorFunction failed");)
  
  return result;
}
modelica_boolean OMCInterface::isOperatorRecord(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isOperatorRecord("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isOperatorRecord(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isOperatorRecord failed");)
  
  return result;
}
modelica_boolean OMCInterface::isOperator(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isOperator("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isOperator(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isOperator failed");)
  
  return result;
}
modelica_boolean OMCInterface::isEnumeration(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isEnumeration("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isEnumeration(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isEnumeration failed");)
  
  return result;
}
modelica_boolean OMCInterface::isOptimization(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isOptimization("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isOptimization(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isOptimization failed");)
  
  return result;
}
modelica_boolean OMCInterface::isConnector(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isConnector("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isConnector(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isConnector failed");)
  
  return result;
}
modelica_boolean OMCInterface::isModel(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isModel("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isModel(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isModel failed");)
  
  return result;
}
modelica_boolean OMCInterface::isPartial(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isPartial("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isPartial(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isPartial failed");)
  
  return result;
}
modelica_boolean OMCInterface::isFunction(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isFunction("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isFunction(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isFunction failed");)
  
  return result;
}
modelica_boolean OMCInterface::isBlock(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isBlock("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isBlock(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isBlock failed");)
  
  return result;
}
modelica_boolean OMCInterface::isRecord(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isRecord("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isRecord(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isRecord failed");)
  
  return result;
}
modelica_boolean OMCInterface::isClass(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isClass("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isClass(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isClass failed");)
  
  return result;
}
modelica_boolean OMCInterface::isPackage(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isPackage("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isPackage(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isPackage failed");)
  
  return result;
}
modelica_boolean OMCInterface::isType(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isType("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isType(threadData, st, mmc_mk_scon(cl_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isType failed");)
  
  return result;
}
QString OMCInterface::getClassRestriction(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getClassRestriction("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getClassRestriction(threadData, st, mmc_mk_scon(cl_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getClassRestriction failed");)
  
  return result;
}
QString OMCInterface::basename(QString path)
{
  QByteArray path_utf8 = path.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("basename("+path+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_basename(threadData, st, mmc_mk_scon(path_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("basename failed");)
  
  return result;
}
QString OMCInterface::dirname(QString path)
{
  QByteArray path_utf8 = path.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("dirname("+path+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_dirname(threadData, st, mmc_mk_scon(path_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("dirname failed");)
  
  return result;
}
QString OMCInterface::getClassComment(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getClassComment("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getClassComment(threadData, st, mmc_mk_scon(cl_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getClassComment failed");)
  
  return result;
}
QList<QString > OMCInterface::typeNameStrings(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("typeNameStrings("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_typeNameStrings(threadData, st, mmc_mk_scon(cl_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("typeNameStrings failed");)
  
  return result;
}
QString OMCInterface::typeNameString(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("typeNameString("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_typeNameString(threadData, st, mmc_mk_scon(cl_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("typeNameString failed");)
  
  return result;
}
QString OMCInterface::stringTypeName(QString str)
{
  QByteArray str_utf8 = str.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("stringTypeName("+str+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_stringTypeName(threadData, st, mmc_mk_scon(str_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append(result);
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("stringTypeName failed");)
  
  return result;
}
OMCInterface::getTimeStamp_res OMCInterface::getTimeStamp(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  getTimeStamp_res result;
  void *out2_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getTimeStamp("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getTimeStamp(threadData, st, mmc_mk_scon(cl_utf8.data()), &result.timeStamp, &out2_mm);
  result.timeStampAsString = QString::fromUtf8(MMC_STRINGDATA(out2_mm));
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getTimeStamp failed");)
  
  return result;
}
modelica_boolean OMCInterface::setDocumentationAnnotation(QString class_, QString info, QString revisions)
{
  QByteArray class__utf8 = class_.toUtf8();
  QByteArray info_utf8 = info.toUtf8();
  QByteArray revisions_utf8 = revisions.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setDocumentationAnnotation("+class_+"," +info+"," +revisions+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setDocumentationAnnotation(threadData, st, mmc_mk_scon(class__utf8.data()), mmc_mk_scon(info_utf8.data()), mmc_mk_scon(revisions_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setDocumentationAnnotation failed");)
  
  return result;
}
QList<QString > OMCInterface::getDocumentationAnnotation(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getDocumentationAnnotation("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getDocumentationAnnotation(threadData, st, mmc_mk_scon(cl_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getDocumentationAnnotation failed");)
  
  return result;
}
QString OMCInterface::iconv(QString string, QString from, QString to)
{
  QByteArray string_utf8 = string.toUtf8();
  QByteArray from_utf8 = from.toUtf8();
  QByteArray to_utf8 = to.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("iconv("+string+"," +from+"," +to+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_iconv(threadData, st, mmc_mk_scon(string_utf8.data()), mmc_mk_scon(from_utf8.data()), mmc_mk_scon(to_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("iconv failed");)
  
  return result;
}
QList<QString > OMCInterface::getNthImport(QString class_, modelica_integer index)
{
  QByteArray class__utf8 = class_.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNthImport("+class_+"," +QString::number(index)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNthImport(threadData, st, mmc_mk_scon(class__utf8.data()), index, &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNthImport failed");)
  
  return result;
}
modelica_integer OMCInterface::getImportCount(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getImportCount("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getImportCount(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getImportCount failed");)
  
  return result;
}
QString OMCInterface::getNthAnnotationString(QString class_, modelica_integer index)
{
  QByteArray class__utf8 = class_.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNthAnnotationString("+class_+"," +QString::number(index)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNthAnnotationString(threadData, st, mmc_mk_scon(class__utf8.data()), index, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNthAnnotationString failed");)
  
  return result;
}
modelica_integer OMCInterface::getAnnotationCount(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getAnnotationCount("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getAnnotationCount(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getAnnotationCount failed");)
  
  return result;
}
QString OMCInterface::getNthInitialEquationItem(QString class_, modelica_integer index)
{
  QByteArray class__utf8 = class_.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNthInitialEquationItem("+class_+"," +QString::number(index)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNthInitialEquationItem(threadData, st, mmc_mk_scon(class__utf8.data()), index, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNthInitialEquationItem failed");)
  
  return result;
}
modelica_integer OMCInterface::getInitialEquationItemsCount(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getInitialEquationItemsCount("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getInitialEquationItemsCount(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getInitialEquationItemsCount failed");)
  
  return result;
}
QString OMCInterface::getNthEquationItem(QString class_, modelica_integer index)
{
  QByteArray class__utf8 = class_.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNthEquationItem("+class_+"," +QString::number(index)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNthEquationItem(threadData, st, mmc_mk_scon(class__utf8.data()), index, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNthEquationItem failed");)
  
  return result;
}
modelica_integer OMCInterface::getEquationItemsCount(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getEquationItemsCount("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getEquationItemsCount(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getEquationItemsCount failed");)
  
  return result;
}
QString OMCInterface::getNthInitialEquation(QString class_, modelica_integer index)
{
  QByteArray class__utf8 = class_.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNthInitialEquation("+class_+"," +QString::number(index)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNthInitialEquation(threadData, st, mmc_mk_scon(class__utf8.data()), index, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNthInitialEquation failed");)
  
  return result;
}
modelica_integer OMCInterface::getInitialEquationCount(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getInitialEquationCount("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getInitialEquationCount(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getInitialEquationCount failed");)
  
  return result;
}
QString OMCInterface::getNthEquation(QString class_, modelica_integer index)
{
  QByteArray class__utf8 = class_.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNthEquation("+class_+"," +QString::number(index)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNthEquation(threadData, st, mmc_mk_scon(class__utf8.data()), index, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNthEquation failed");)
  
  return result;
}
modelica_integer OMCInterface::getEquationCount(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getEquationCount("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getEquationCount(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getEquationCount failed");)
  
  return result;
}
QString OMCInterface::getNthInitialAlgorithmItem(QString class_, modelica_integer index)
{
  QByteArray class__utf8 = class_.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNthInitialAlgorithmItem("+class_+"," +QString::number(index)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNthInitialAlgorithmItem(threadData, st, mmc_mk_scon(class__utf8.data()), index, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNthInitialAlgorithmItem failed");)
  
  return result;
}
modelica_integer OMCInterface::getInitialAlgorithmItemsCount(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getInitialAlgorithmItemsCount("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getInitialAlgorithmItemsCount(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getInitialAlgorithmItemsCount failed");)
  
  return result;
}
QString OMCInterface::getNthAlgorithmItem(QString class_, modelica_integer index)
{
  QByteArray class__utf8 = class_.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNthAlgorithmItem("+class_+"," +QString::number(index)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNthAlgorithmItem(threadData, st, mmc_mk_scon(class__utf8.data()), index, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNthAlgorithmItem failed");)
  
  return result;
}
modelica_integer OMCInterface::getAlgorithmItemsCount(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getAlgorithmItemsCount("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getAlgorithmItemsCount(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getAlgorithmItemsCount failed");)
  
  return result;
}
QString OMCInterface::getNthInitialAlgorithm(QString class_, modelica_integer index)
{
  QByteArray class__utf8 = class_.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNthInitialAlgorithm("+class_+"," +QString::number(index)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNthInitialAlgorithm(threadData, st, mmc_mk_scon(class__utf8.data()), index, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNthInitialAlgorithm failed");)
  
  return result;
}
modelica_integer OMCInterface::getInitialAlgorithmCount(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getInitialAlgorithmCount("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getInitialAlgorithmCount(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getInitialAlgorithmCount failed");)
  
  return result;
}
QString OMCInterface::getNthAlgorithm(QString class_, modelica_integer index)
{
  QByteArray class__utf8 = class_.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNthAlgorithm("+class_+"," +QString::number(index)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNthAlgorithm(threadData, st, mmc_mk_scon(class__utf8.data()), index, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNthAlgorithm failed");)
  
  return result;
}
modelica_integer OMCInterface::getAlgorithmCount(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getAlgorithmCount("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getAlgorithmCount(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getAlgorithmCount failed");)
  
  return result;
}
QList<QString > OMCInterface::getComponentModifierNames(QString class_, QString componentName)
{
  QByteArray class__utf8 = class_.toUtf8();
  QByteArray componentName_utf8 = componentName.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getComponentModifierNames("+class_+"," +componentName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getComponentModifierNames(threadData, st, mmc_mk_scon(class__utf8.data()), mmc_mk_scon(componentName_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getComponentModifierNames failed");)
  
  return result;
}
QString OMCInterface::getParameterValue(QString class_, QString parameterName)
{
  QByteArray class__utf8 = class_.toUtf8();
  QByteArray parameterName_utf8 = parameterName.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getParameterValue("+class_+"," +parameterName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getParameterValue(threadData, st, mmc_mk_scon(class__utf8.data()), mmc_mk_scon(parameterName_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getParameterValue failed");)
  
  return result;
}
QList<QString > OMCInterface::getParameterNames(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getParameterNames("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getParameterNames(threadData, st, mmc_mk_scon(class__utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getParameterNames failed");)
  
  return result;
}
modelica_boolean OMCInterface::closeSimulationResultFile()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("closeSimulationResultFile("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_closeSimulationResultFile(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("closeSimulationResultFile failed");)
  
  return result;
}
QList<QString > OMCInterface::checkCodeGraph(QString graphfile, QString codefile)
{
  QByteArray graphfile_utf8 = graphfile.toUtf8();
  QByteArray codefile_utf8 = codefile.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("checkCodeGraph("+graphfile+"," +codefile+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_checkCodeGraph(threadData, st, mmc_mk_scon(graphfile_utf8.data()), mmc_mk_scon(codefile_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("checkCodeGraph failed");)
  
  return result;
}
QList<QString > OMCInterface::checkTaskGraph(QString filename, QString reffilename)
{
  QByteArray filename_utf8 = filename.toUtf8();
  QByteArray reffilename_utf8 = reffilename.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("checkTaskGraph("+filename+"," +reffilename+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_checkTaskGraph(threadData, st, mmc_mk_scon(filename_utf8.data()), mmc_mk_scon(reffilename_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("checkTaskGraph failed");)
  
  return result;
}
QString OMCInterface::diffSimulationResultsHtml(QString var, QString actualFile, QString expectedFile, modelica_real relTol, modelica_real relTolDiffMinMax, modelica_real rangeDelta)
{
  QByteArray var_utf8 = var.toUtf8();
  QByteArray actualFile_utf8 = actualFile.toUtf8();
  QByteArray expectedFile_utf8 = expectedFile.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("diffSimulationResultsHtml("+var+"," +actualFile+"," +expectedFile+"," +QString::number(relTol)+"," +QString::number(relTolDiffMinMax)+"," +QString::number(rangeDelta)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_diffSimulationResultsHtml(threadData, st, mmc_mk_scon(var_utf8.data()), mmc_mk_scon(actualFile_utf8.data()), mmc_mk_scon(expectedFile_utf8.data()), relTol, relTolDiffMinMax, rangeDelta, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("diffSimulationResultsHtml failed");)
  
  return result;
}
OMCInterface::diffSimulationResults_res OMCInterface::diffSimulationResults(QString actualFile, QString expectedFile, QString diffPrefix, modelica_real relTol, modelica_real relTolDiffMinMax, modelica_real rangeDelta, QList<QString > vars, modelica_boolean keepEqualResults)
{
  QByteArray actualFile_utf8 = actualFile.toUtf8();
  QByteArray expectedFile_utf8 = expectedFile.toUtf8();
  QByteArray diffPrefix_utf8 = diffPrefix.toUtf8();
  void *vars_lst = mmc_mk_nil();
  for (int vars_i = vars.size()-1; vars_i>=0; vars_i--) {
    QString vars_elt = vars[vars_i];
    QByteArray vars_elt_utf8 = vars_elt.toUtf8();
    vars_lst = mmc_mk_cons(mmc_mk_scon(vars_elt_utf8.data()), vars_lst);
  }
  diffSimulationResults_res result;
  void *out2_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("diffSimulationResults("+actualFile+"," +expectedFile+"," +diffPrefix+"," +QString::number(relTol)+"," +QString::number(relTolDiffMinMax)+"," +QString::number(rangeDelta)+"," +QString("### Handle array arguments ###")+"," +QString(keepEqualResults ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_diffSimulationResults(threadData, st, mmc_mk_scon(actualFile_utf8.data()), mmc_mk_scon(expectedFile_utf8.data()), mmc_mk_scon(diffPrefix_utf8.data()), relTol, relTolDiffMinMax, rangeDelta, vars_lst, keepEqualResults, &result.success, &out2_mm);
  result.resultFiles.clear();
  while (!listEmpty(out2_mm)) {
    QString out2_elt;
    out2_elt = MMC_STRINGDATA(MMC_CAR(out2_mm));
    result.resultFiles.push_back(out2_elt);
    out2_mm = MMC_CDR(out2_mm);
  }
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("diffSimulationResults failed");)
  
  return result;
}
QList<QString > OMCInterface::compareSimulationResults(QString filename, QString reffilename, QString logfilename, modelica_real relTol, modelica_real absTol, QList<QString > vars)
{
  QByteArray filename_utf8 = filename.toUtf8();
  QByteArray reffilename_utf8 = reffilename.toUtf8();
  QByteArray logfilename_utf8 = logfilename.toUtf8();
  void *vars_lst = mmc_mk_nil();
  for (int vars_i = vars.size()-1; vars_i>=0; vars_i--) {
    QString vars_elt = vars[vars_i];
    QByteArray vars_elt_utf8 = vars_elt.toUtf8();
    vars_lst = mmc_mk_cons(mmc_mk_scon(vars_elt_utf8.data()), vars_lst);
  }
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("compareSimulationResults("+filename+"," +reffilename+"," +logfilename+"," +QString::number(relTol)+"," +QString::number(absTol)+"," +QString("### Handle array arguments ###")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_compareSimulationResults(threadData, st, mmc_mk_scon(filename_utf8.data()), mmc_mk_scon(reffilename_utf8.data()), mmc_mk_scon(logfilename_utf8.data()), relTol, absTol, vars_lst, &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("compareSimulationResults failed");)
  
  return result;
}
QList<QString > OMCInterface::readSimulationResultVars(QString fileName, modelica_boolean readParameters)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("readSimulationResultVars("+fileName+"," +QString(readParameters ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_readSimulationResultVars(threadData, st, mmc_mk_scon(fileName_utf8.data()), readParameters, &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("readSimulationResultVars failed");)
  
  return result;
}
modelica_integer OMCInterface::readSimulationResultSize(QString fileName)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("readSimulationResultSize("+fileName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_readSimulationResultSize(threadData, st, mmc_mk_scon(fileName_utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("readSimulationResultSize failed");)
  
  return result;
}
modelica_boolean OMCInterface::visualize(QString className, modelica_boolean externalWindow, QString fileName)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray fileName_utf8 = fileName.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("visualize("+className+"," +QString(externalWindow ? "true" : "false")+"," +fileName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_visualize(threadData, st, mmc_mk_scon(className_utf8.data()), externalWindow, mmc_mk_scon(fileName_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("visualize failed");)
  
  return result;
}
OMCInterface::plotAll_res OMCInterface::plotAll(modelica_boolean externalWindow, QString fileName, QString title, QString grid, modelica_boolean logX, modelica_boolean logY, QString xLabel, QString yLabel, QList<modelica_real > xRange, QList<modelica_real > yRange, modelica_real curveWidth, modelica_integer curveStyle, QString legendPosition, QString footer)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QByteArray title_utf8 = title.toUtf8();
  QByteArray grid_utf8 = grid.toUtf8();
  QByteArray xLabel_utf8 = xLabel.toUtf8();
  QByteArray yLabel_utf8 = yLabel.toUtf8();
  void *xRange_lst = mmc_mk_nil();
  for (int xRange_i = xRange.size()-1; xRange_i>=0; xRange_i--) {
    modelica_real xRange_elt = xRange[xRange_i];
    xRange_lst = mmc_mk_cons(mmc_mk_rcon(xRange_elt), xRange_lst);
  }
  void *yRange_lst = mmc_mk_nil();
  for (int yRange_i = yRange.size()-1; yRange_i>=0; yRange_i--) {
    modelica_real yRange_elt = yRange[yRange_i];
    yRange_lst = mmc_mk_cons(mmc_mk_rcon(yRange_elt), yRange_lst);
  }
  QByteArray legendPosition_utf8 = legendPosition.toUtf8();
  QByteArray footer_utf8 = footer.toUtf8();
  plotAll_res result;
  void *out2_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("plotAll("+QString(externalWindow ? "true" : "false")+"," +fileName+"," +title+"," +grid+"," +QString(logX ? "true" : "false")+"," +QString(logY ? "true" : "false")+"," +xLabel+"," +yLabel+"," +QString("### Handle array arguments ###")+"," +QString("### Handle array arguments ###")+"," +QString::number(curveWidth)+"," +QString::number(curveStyle)+"," +legendPosition+"," +footer+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_plotAll(threadData, st, externalWindow, mmc_mk_scon(fileName_utf8.data()), mmc_mk_scon(title_utf8.data()), mmc_mk_scon(grid_utf8.data()), logX, logY, mmc_mk_scon(xLabel_utf8.data()), mmc_mk_scon(yLabel_utf8.data()), xRange_lst, yRange_lst, curveWidth, curveStyle, mmc_mk_scon(legendPosition_utf8.data()), mmc_mk_scon(footer_utf8.data()), &result.success, &out2_mm);
  result.result.clear();
  while (!listEmpty(out2_mm)) {
    QString out2_elt;
    out2_elt = MMC_STRINGDATA(MMC_CAR(out2_mm));
    result.result.push_back(out2_elt);
    out2_mm = MMC_CDR(out2_mm);
  }
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("plotAll failed");)
  
  return result;
}
modelica_boolean OMCInterface::getPlotSilent()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getPlotSilent("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getPlotSilent(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getPlotSilent failed");)
  
  return result;
}
QList<QString > OMCInterface::getPackages(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getPackages("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getPackages(threadData, st, mmc_mk_scon(class__utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(result_elt);
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getPackages failed");)
  
  return result;
}
QList<QString > OMCInterface::getUsedClassNames(QString className)
{
  QByteArray className_utf8 = className.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getUsedClassNames("+className+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getUsedClassNames(threadData, st, mmc_mk_scon(className_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(result_elt);
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getUsedClassNames failed");)
  
  return result;
}
QList<QString > OMCInterface::getClassNames(QString class_, modelica_boolean recursive, modelica_boolean qualified, modelica_boolean sort, modelica_boolean builtin, modelica_boolean showProtected)
{
  QByteArray class__utf8 = class_.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getClassNames("+class_+"," +QString(recursive ? "true" : "false")+"," +QString(qualified ? "true" : "false")+"," +QString(sort ? "true" : "false")+"," +QString(builtin ? "true" : "false")+"," +QString(showProtected ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getClassNames(threadData, st, mmc_mk_scon(class__utf8.data()), recursive, qualified, sort, builtin, showProtected, &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(result_elt);
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getClassNames failed");)
  
  return result;
}
modelica_boolean OMCInterface::setClassComment(QString class_, QString filename)
{
  QByteArray class__utf8 = class_.toUtf8();
  QByteArray filename_utf8 = filename.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setClassComment("+class_+"," +filename+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setClassComment(threadData, st, mmc_mk_scon(class__utf8.data()), mmc_mk_scon(filename_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setClassComment failed");)
  
  return result;
}
modelica_boolean OMCInterface::isShortDefinition(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("isShortDefinition("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_isShortDefinition(threadData, st, mmc_mk_scon(class__utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("isShortDefinition failed");)
  
  return result;
}
modelica_boolean OMCInterface::setSourceFile(QString class_, QString filename)
{
  QByteArray class__utf8 = class_.toUtf8();
  QByteArray filename_utf8 = filename.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setSourceFile("+class_+"," +filename+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setSourceFile(threadData, st, mmc_mk_scon(class__utf8.data()), mmc_mk_scon(filename_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setSourceFile failed");)
  
  return result;
}
QString OMCInterface::getSourceFile(QString class_)
{
  QByteArray class__utf8 = class_.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getSourceFile("+class_+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getSourceFile(threadData, st, mmc_mk_scon(class__utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getSourceFile failed");)
  
  return result;
}
modelica_boolean OMCInterface::copyClass(QString className, QString newClassName, QString withIn)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray newClassName_utf8 = newClassName.toUtf8();
  QByteArray withIn_utf8 = withIn.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("copyClass("+className+"," +newClassName+"," +withIn+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_copyClass(threadData, st, mmc_mk_scon(className_utf8.data()), mmc_mk_scon(newClassName_utf8.data()), mmc_mk_scon(withIn_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("copyClass failed");)
  
  return result;
}
modelica_boolean OMCInterface::moveClass(QString className, QString direction)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray direction_utf8 = direction.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("moveClass("+className+"," +direction+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_moveClass(threadData, st, mmc_mk_scon(className_utf8.data()), mmc_mk_scon(direction_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("moveClass failed");)
  
  return result;
}
QString OMCInterface::translateModelFMU(QString className, QString version, QString fmuType, QString fileNamePrefix)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray version_utf8 = version.toUtf8();
  QByteArray fmuType_utf8 = fmuType.toUtf8();
  QByteArray fileNamePrefix_utf8 = fileNamePrefix.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("translateModelFMU("+className+"," +version+"," +fmuType+"," +fileNamePrefix+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_translateModelFMU(threadData, st, mmc_mk_scon(className_utf8.data()), mmc_mk_scon(version_utf8.data()), mmc_mk_scon(fmuType_utf8.data()), mmc_mk_scon(fileNamePrefix_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("translateModelFMU failed");)
  
  return result;
}
QString OMCInterface::importFMU(QString filename, QString workdir, modelica_integer loglevel, modelica_boolean fullPath, modelica_boolean debugLogging, modelica_boolean generateInputConnectors, modelica_boolean generateOutputConnectors)
{
  QByteArray filename_utf8 = filename.toUtf8();
  QByteArray workdir_utf8 = workdir.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("importFMU("+filename+"," +workdir+"," +QString::number(loglevel)+"," +QString(fullPath ? "true" : "false")+"," +QString(debugLogging ? "true" : "false")+"," +QString(generateInputConnectors ? "true" : "false")+"," +QString(generateOutputConnectors ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_importFMU(threadData, st, mmc_mk_scon(filename_utf8.data()), mmc_mk_scon(workdir_utf8.data()), loglevel, fullPath, debugLogging, generateInputConnectors, generateOutputConnectors, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("importFMU failed");)
  
  return result;
}
QList<QList<QString > > OMCInterface::getLoadedLibraries()
{
  QList<QList<QString > > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getLoadedLibraries("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getLoadedLibraries(threadData, st, &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QList<QString > result_elt;
    result_elt.clear();
    while (!listEmpty(MMC_CAR(result_mm))) {
      QString result_elt_elt;
      result_elt_elt = MMC_STRINGDATA(MMC_CAR(MMC_CAR(result_mm)));
      result_elt.push_back(result_elt_elt);
      MMC_CAR(result_mm) = MMC_CDR(MMC_CAR(result_mm));
    }
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QList<QString > result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("{");
    int result_elt_i = 0;
    foreach(QString result_elt_elt, result_elt) {
      if (result_elt_i) {
        responseLog.append(",");
      }
      responseLog.append("\"" + result_elt_elt + "\"");
      result_elt_i++;
    }
    responseLog.append("}");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getLoadedLibraries failed");)
  
  return result;
}
modelica_boolean OMCInterface::rewriteBlockCall(QString className, QString inDefs)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray inDefs_utf8 = inDefs.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("rewriteBlockCall("+className+"," +inDefs+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_rewriteBlockCall(threadData, st, mmc_mk_scon(className_utf8.data()), mmc_mk_scon(inDefs_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("rewriteBlockCall failed");)
  
  return result;
}
modelica_boolean OMCInterface::exportToFigaro(QString path, QString directory, QString database, QString mode, QString options, QString processor)
{
  QByteArray path_utf8 = path.toUtf8();
  QByteArray directory_utf8 = directory.toUtf8();
  QByteArray database_utf8 = database.toUtf8();
  QByteArray mode_utf8 = mode.toUtf8();
  QByteArray options_utf8 = options.toUtf8();
  QByteArray processor_utf8 = processor.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("exportToFigaro("+path+"," +directory+"," +database+"," +mode+"," +options+"," +processor+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_exportToFigaro(threadData, st, mmc_mk_scon(path_utf8.data()), mmc_mk_scon(directory_utf8.data()), mmc_mk_scon(database_utf8.data()), mmc_mk_scon(mode_utf8.data()), mmc_mk_scon(options_utf8.data()), mmc_mk_scon(processor_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("exportToFigaro failed");)
  
  return result;
}
QString OMCInterface::stringReplace(QString str, QString source, QString target)
{
  QByteArray str_utf8 = str.toUtf8();
  QByteArray source_utf8 = source.toUtf8();
  QByteArray target_utf8 = target.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("stringReplace("+str+"," +source+"," +target+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_stringReplace(threadData, st, mmc_mk_scon(str_utf8.data()), mmc_mk_scon(source_utf8.data()), mmc_mk_scon(target_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("stringReplace failed");)
  
  return result;
}
QList<QString > OMCInterface::strtok(QString string, QString token)
{
  QByteArray string_utf8 = string.toUtf8();
  QByteArray token_utf8 = token.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("strtok("+string+"," +token+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_strtok(threadData, st, mmc_mk_scon(string_utf8.data()), mmc_mk_scon(token_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("strtok failed");)
  
  return result;
}
QList<QString > OMCInterface::listVariables()
{
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("listVariables("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_listVariables(threadData, st, &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(result_elt);
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("listVariables failed");)
  
  return result;
}
OMCInterface::convertUnits_res OMCInterface::convertUnits(QString s1, QString s2)
{
  QByteArray s1_utf8 = s1.toUtf8();
  QByteArray s2_utf8 = s2.toUtf8();
  convertUnits_res result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("convertUnits("+s1+"," +s2+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_convertUnits(threadData, st, mmc_mk_scon(s1_utf8.data()), mmc_mk_scon(s2_utf8.data()), &result.unitsCompatible, &result.scaleFactor1, &result.offset1, &result.scaleFactor2, &result.offset2);
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("convertUnits failed");)
  
  return result;
}
OMCInterface::dumpXMLDAE_res OMCInterface::dumpXMLDAE(QString className, QString translationLevel, modelica_boolean addOriginalIncidenceMatrix, modelica_boolean addSolvingInfo, modelica_boolean addMathMLCode, modelica_boolean dumpResiduals, QString fileNamePrefix, QString rewriteRulesFile)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray translationLevel_utf8 = translationLevel.toUtf8();
  QByteArray fileNamePrefix_utf8 = fileNamePrefix.toUtf8();
  QByteArray rewriteRulesFile_utf8 = rewriteRulesFile.toUtf8();
  dumpXMLDAE_res result;
  void *out2_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("dumpXMLDAE("+className+"," +translationLevel+"," +QString(addOriginalIncidenceMatrix ? "true" : "false")+"," +QString(addSolvingInfo ? "true" : "false")+"," +QString(addMathMLCode ? "true" : "false")+"," +QString(dumpResiduals ? "true" : "false")+"," +fileNamePrefix+"," +rewriteRulesFile+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_dumpXMLDAE(threadData, st, mmc_mk_scon(className_utf8.data()), mmc_mk_scon(translationLevel_utf8.data()), addOriginalIncidenceMatrix, addSolvingInfo, addMathMLCode, dumpResiduals, mmc_mk_scon(fileNamePrefix_utf8.data()), mmc_mk_scon(rewriteRulesFile_utf8.data()), &result.success, &out2_mm);
  result.xmlfileName = QString::fromUtf8(MMC_STRINGDATA(out2_mm));
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("dumpXMLDAE failed");)
  
  return result;
}
QString OMCInterface::translateGraphics(QString className)
{
  QByteArray className_utf8 = className.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("translateGraphics("+className+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_translateGraphics(threadData, st, mmc_mk_scon(className_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("translateGraphics failed");)
  
  return result;
}
modelica_boolean OMCInterface::save(QString className)
{
  QByteArray className_utf8 = className.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("save("+className+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_save(threadData, st, mmc_mk_scon(className_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("save failed");)
  
  return result;
}
modelica_boolean OMCInterface::saveTotalModel(QString fileName, QString className)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QByteArray className_utf8 = className.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("saveTotalModel("+fileName+"," +className+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_saveTotalModel(threadData, st, mmc_mk_scon(fileName_utf8.data()), mmc_mk_scon(className_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("saveTotalModel failed");)
  
  return result;
}
modelica_boolean OMCInterface::saveModel(QString fileName, QString className)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QByteArray className_utf8 = className.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("saveModel("+fileName+"," +className+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_saveModel(threadData, st, mmc_mk_scon(fileName_utf8.data()), mmc_mk_scon(className_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("saveModel failed");)
  
  return result;
}
modelica_boolean OMCInterface::deleteFile(QString fileName)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("deleteFile("+fileName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_deleteFile(threadData, st, mmc_mk_scon(fileName_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("deleteFile failed");)
  
  return result;
}
modelica_boolean OMCInterface::loadModel(QString className, QList<QString > priorityVersion, modelica_boolean notify, QString languageStandard, modelica_boolean requireExactVersion)
{
  QByteArray className_utf8 = className.toUtf8();
  void *priorityVersion_lst = mmc_mk_nil();
  for (int priorityVersion_i = priorityVersion.size()-1; priorityVersion_i>=0; priorityVersion_i--) {
    QString priorityVersion_elt = priorityVersion[priorityVersion_i];
    QByteArray priorityVersion_elt_utf8 = priorityVersion_elt.toUtf8();
    priorityVersion_lst = mmc_mk_cons(mmc_mk_scon(priorityVersion_elt_utf8.data()), priorityVersion_lst);
  }
  QByteArray languageStandard_utf8 = languageStandard.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("loadModel("+className+"," +QString("### Handle array arguments ###")+"," +QString(notify ? "true" : "false")+"," +languageStandard+"," +QString(requireExactVersion ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_loadModel(threadData, st, mmc_mk_scon(className_utf8.data()), priorityVersion_lst, notify, mmc_mk_scon(languageStandard_utf8.data()), requireExactVersion, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("loadModel failed");)
  
  return result;
}
modelica_boolean OMCInterface::generateCode(QString className)
{
  QByteArray className_utf8 = className.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("generateCode("+className+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_generateCode(threadData, st, mmc_mk_scon(className_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("generateCode failed");)
  
  return result;
}
QString OMCInterface::runOpenTURNSPythonScript(QString pythonScriptFile)
{
  QByteArray pythonScriptFile_utf8 = pythonScriptFile.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("runOpenTURNSPythonScript("+pythonScriptFile+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_runOpenTURNSPythonScript(threadData, st, mmc_mk_scon(pythonScriptFile_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("runOpenTURNSPythonScript failed");)
  
  return result;
}
QString OMCInterface::buildOpenTURNSInterface(QString className, QString pythonTemplateFile, modelica_boolean showFlatModelica)
{
  QByteArray className_utf8 = className.toUtf8();
  QByteArray pythonTemplateFile_utf8 = pythonTemplateFile.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("buildOpenTURNSInterface("+className+"," +pythonTemplateFile+"," +QString(showFlatModelica ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_buildOpenTURNSInterface(threadData, st, mmc_mk_scon(className_utf8.data()), mmc_mk_scon(pythonTemplateFile_utf8.data()), showFlatModelica, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("buildOpenTURNSInterface failed");)
  
  return result;
}
QString OMCInterface::instantiateModel(QString className)
{
  QByteArray className_utf8 = className.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("instantiateModel("+className+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_instantiateModel(threadData, st, mmc_mk_scon(className_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("instantiateModel failed");)
  
  return result;
}
QString OMCInterface::checkAllModelsRecursive(QString className, modelica_boolean checkProtected)
{
  QByteArray className_utf8 = className.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("checkAllModelsRecursive("+className+"," +QString(checkProtected ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_checkAllModelsRecursive(threadData, st, mmc_mk_scon(className_utf8.data()), checkProtected, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("checkAllModelsRecursive failed");)
  
  return result;
}
QString OMCInterface::checkModel(QString className)
{
  QByteArray className_utf8 = className.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("checkModel("+className+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_checkModel(threadData, st, mmc_mk_scon(className_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("checkModel failed");)
  
  return result;
}
modelica_boolean OMCInterface::remove(QString newDirectory)
{
  QByteArray newDirectory_utf8 = newDirectory.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("remove("+newDirectory+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_remove(threadData, st, mmc_mk_scon(newDirectory_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("remove failed");)
  
  return result;
}
modelica_boolean OMCInterface::mkdir(QString newDirectory)
{
  QByteArray newDirectory_utf8 = newDirectory.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("mkdir("+newDirectory+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_mkdir(threadData, st, mmc_mk_scon(newDirectory_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("mkdir failed");)
  
  return result;
}
QString OMCInterface::cd(QString newWorkingDirectory)
{
  QByteArray newWorkingDirectory_utf8 = newWorkingDirectory.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("cd("+newWorkingDirectory+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_cd(threadData, st, mmc_mk_scon(newWorkingDirectory_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("cd failed");)
  
  return result;
}
QString OMCInterface::getAstAsCorbaString(QString fileName)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getAstAsCorbaString("+fileName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getAstAsCorbaString(threadData, st, mmc_mk_scon(fileName_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getAstAsCorbaString failed");)
  
  return result;
}
QString OMCInterface::getLanguageStandard()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getLanguageStandard("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getLanguageStandard(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getLanguageStandard failed");)
  
  return result;
}
modelica_boolean OMCInterface::getOrderConnections()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getOrderConnections("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getOrderConnections(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getOrderConnections failed");)
  
  return result;
}
modelica_boolean OMCInterface::getShowAnnotations()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getShowAnnotations("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getShowAnnotations(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getShowAnnotations failed");)
  
  return result;
}
modelica_boolean OMCInterface::setShowAnnotations(modelica_boolean show)
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setShowAnnotations("+QString(show ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setShowAnnotations(threadData, st, show, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setShowAnnotations failed");)
  
  return result;
}
modelica_integer OMCInterface::getDefaultOpenCLDevice()
{
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getDefaultOpenCLDevice("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getDefaultOpenCLDevice(threadData, st, &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getDefaultOpenCLDevice failed");)
  
  return result;
}
modelica_integer OMCInterface::getVectorizationLimit()
{
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getVectorizationLimit("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getVectorizationLimit(threadData, st, &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getVectorizationLimit failed");)
  
  return result;
}
modelica_boolean OMCInterface::setNoSimplify(modelica_boolean noSimplify)
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setNoSimplify("+QString(noSimplify ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setNoSimplify(threadData, st, noSimplify, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setNoSimplify failed");)
  
  return result;
}
modelica_boolean OMCInterface::getNoSimplify()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getNoSimplify("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getNoSimplify(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getNoSimplify failed");)
  
  return result;
}
QString OMCInterface::getAnnotationVersion()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getAnnotationVersion("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getAnnotationVersion(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getAnnotationVersion failed");)
  
  return result;
}
QString OMCInterface::getClassesInModelicaPath()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getClassesInModelicaPath("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getClassesInModelicaPath(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getClassesInModelicaPath failed");)
  
  return result;
}
modelica_boolean OMCInterface::echo(modelica_boolean setEcho)
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("echo("+QString(setEcho ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_echo(threadData, st, setEcho, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("echo failed");)
  
  return result;
}
QString OMCInterface::runScript(QString fileName)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("runScript("+fileName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_runScript(threadData, st, mmc_mk_scon(fileName_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("runScript failed");)
  
  return result;
}
modelica_boolean OMCInterface::clearMessages()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("clearMessages("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_clearMessages(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("clearMessages failed");)
  
  return result;
}
OMCInterface::countMessages_res OMCInterface::countMessages()
{
  countMessages_res result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("countMessages("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_countMessages(threadData, st, &result.numMessages, &result.numErrors, &result.numWarnings);
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("countMessages failed");)
  
  return result;
}
QString OMCInterface::getMessagesString()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getMessagesString("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getMessagesString(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getMessagesString failed");)
  
  return result;
}
QString OMCInterface::getErrorString(modelica_boolean warningsAsErrors)
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getErrorString("+QString(warningsAsErrors ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getErrorString(threadData, st, warningsAsErrors, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getErrorString failed");)
  
  return result;
}
QString OMCInterface::readFileNoNumeric(QString fileName)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("readFileNoNumeric("+fileName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_readFileNoNumeric(threadData, st, mmc_mk_scon(fileName_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("readFileNoNumeric failed");)
  
  return result;
}
modelica_integer OMCInterface::alarm(modelica_integer seconds)
{
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("alarm("+QString::number(seconds)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_alarm(threadData, st, seconds, &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("alarm failed");)
  
  return result;
}
modelica_boolean OMCInterface::compareFiles(QString file1, QString file2)
{
  QByteArray file1_utf8 = file1.toUtf8();
  QByteArray file2_utf8 = file2.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("compareFiles("+file1+"," +file2+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_compareFiles(threadData, st, mmc_mk_scon(file1_utf8.data()), mmc_mk_scon(file2_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("compareFiles failed");)
  
  return result;
}
modelica_boolean OMCInterface::compareFilesAndMove(QString newFile, QString oldFile)
{
  QByteArray newFile_utf8 = newFile.toUtf8();
  QByteArray oldFile_utf8 = oldFile.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("compareFilesAndMove("+newFile+"," +oldFile+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_compareFilesAndMove(threadData, st, mmc_mk_scon(newFile_utf8.data()), mmc_mk_scon(oldFile_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("compareFilesAndMove failed");)
  
  return result;
}
modelica_boolean OMCInterface::writeFile(QString fileName, QString data, modelica_boolean append)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QByteArray data_utf8 = data.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("writeFile("+fileName+"," +data+"," +QString(append ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_writeFile(threadData, st, mmc_mk_scon(fileName_utf8.data()), mmc_mk_scon(data_utf8.data()), append, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("writeFile failed");)
  
  return result;
}
QString OMCInterface::readFile(QString fileName)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("readFile("+fileName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_readFile(threadData, st, mmc_mk_scon(fileName_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("readFile failed");)
  
  return result;
}
QString OMCInterface::getVersion(QString cl)
{
  QByteArray cl_utf8 = cl.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getVersion("+cl+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getVersion(threadData, st, mmc_mk_scon(cl_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getVersion failed");)
  
  return result;
}
modelica_boolean OMCInterface::clearCommandLineOptions()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("clearCommandLineOptions("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_clearCommandLineOptions(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("clearCommandLineOptions failed");)
  
  return result;
}
OMCInterface::getConfigFlagValidOptions_res OMCInterface::getConfigFlagValidOptions(QString flag)
{
  QByteArray flag_utf8 = flag.toUtf8();
  getConfigFlagValidOptions_res result;
  void *out1_mm = NULL;
  void *out2_mm = NULL;
  void *out3_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getConfigFlagValidOptions("+flag+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getConfigFlagValidOptions(threadData, st, mmc_mk_scon(flag_utf8.data()), &out1_mm, &out2_mm, &out3_mm);
  result.validOptions.clear();
  while (!listEmpty(out1_mm)) {
    QString out1_elt;
    out1_elt = MMC_STRINGDATA(MMC_CAR(out1_mm));
    result.validOptions.push_back(out1_elt);
    out1_mm = MMC_CDR(out1_mm);
  }
  result.mainDescription = QString::fromUtf8(MMC_STRINGDATA(out2_mm));
  result.descriptions.clear();
  while (!listEmpty(out3_mm)) {
    QString out3_elt;
    out3_elt = MMC_STRINGDATA(MMC_CAR(out3_mm));
    result.descriptions.push_back(out3_elt);
    out3_mm = MMC_CDR(out3_mm);
  }
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getConfigFlagValidOptions failed");)
  
  return result;
}
modelica_boolean OMCInterface::setCommandLineOptions(QString option)
{
  QByteArray option_utf8 = option.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setCommandLineOptions("+option+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setCommandLineOptions(threadData, st, mmc_mk_scon(option_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setCommandLineOptions failed");)
  
  return result;
}
OMCInterface::getAvailableTearingMethods_res OMCInterface::getAvailableTearingMethods()
{
  getAvailableTearingMethods_res result;
  void *out1_mm = NULL;
  void *out2_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getAvailableTearingMethods("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getAvailableTearingMethods(threadData, st, &out1_mm, &out2_mm);
  result.allChoices.clear();
  while (!listEmpty(out1_mm)) {
    QString out1_elt;
    out1_elt = MMC_STRINGDATA(MMC_CAR(out1_mm));
    result.allChoices.push_back(out1_elt);
    out1_mm = MMC_CDR(out1_mm);
  }
  result.allComments.clear();
  while (!listEmpty(out2_mm)) {
    QString out2_elt;
    out2_elt = MMC_STRINGDATA(MMC_CAR(out2_mm));
    result.allComments.push_back(out2_elt);
    out2_mm = MMC_CDR(out2_mm);
  }
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getAvailableTearingMethods failed");)
  
  return result;
}
QString OMCInterface::getTearingMethod()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getTearingMethod("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getTearingMethod(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getTearingMethod failed");)
  
  return result;
}
OMCInterface::getAvailableIndexReductionMethods_res OMCInterface::getAvailableIndexReductionMethods()
{
  getAvailableIndexReductionMethods_res result;
  void *out1_mm = NULL;
  void *out2_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getAvailableIndexReductionMethods("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getAvailableIndexReductionMethods(threadData, st, &out1_mm, &out2_mm);
  result.allChoices.clear();
  while (!listEmpty(out1_mm)) {
    QString out1_elt;
    out1_elt = MMC_STRINGDATA(MMC_CAR(out1_mm));
    result.allChoices.push_back(out1_elt);
    out1_mm = MMC_CDR(out1_mm);
  }
  result.allComments.clear();
  while (!listEmpty(out2_mm)) {
    QString out2_elt;
    out2_elt = MMC_STRINGDATA(MMC_CAR(out2_mm));
    result.allComments.push_back(out2_elt);
    out2_mm = MMC_CDR(out2_mm);
  }
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getAvailableIndexReductionMethods failed");)
  
  return result;
}
QString OMCInterface::getIndexReductionMethod()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getIndexReductionMethod("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getIndexReductionMethod(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getIndexReductionMethod failed");)
  
  return result;
}
OMCInterface::getAvailableMatchingAlgorithms_res OMCInterface::getAvailableMatchingAlgorithms()
{
  getAvailableMatchingAlgorithms_res result;
  void *out1_mm = NULL;
  void *out2_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getAvailableMatchingAlgorithms("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getAvailableMatchingAlgorithms(threadData, st, &out1_mm, &out2_mm);
  result.allChoices.clear();
  while (!listEmpty(out1_mm)) {
    QString out1_elt;
    out1_elt = MMC_STRINGDATA(MMC_CAR(out1_mm));
    result.allChoices.push_back(out1_elt);
    out1_mm = MMC_CDR(out1_mm);
  }
  result.allComments.clear();
  while (!listEmpty(out2_mm)) {
    QString out2_elt;
    out2_elt = MMC_STRINGDATA(MMC_CAR(out2_mm));
    result.allComments.push_back(out2_elt);
    out2_mm = MMC_CDR(out2_mm);
  }
  QString responseLog;
  responseLog.append(result.toString());
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getAvailableMatchingAlgorithms failed");)
  
  return result;
}
QString OMCInterface::getMatchingAlgorithm()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getMatchingAlgorithm("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getMatchingAlgorithm(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getMatchingAlgorithm failed");)
  
  return result;
}
modelica_boolean OMCInterface::clearDebugFlags()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("clearDebugFlags("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_clearDebugFlags(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("clearDebugFlags failed");)
  
  return result;
}
modelica_boolean OMCInterface::setCompilerFlags(QString compilerFlags)
{
  QByteArray compilerFlags_utf8 = compilerFlags.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setCompilerFlags("+compilerFlags+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setCompilerFlags(threadData, st, mmc_mk_scon(compilerFlags_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setCompilerFlags failed");)
  
  return result;
}
QString OMCInterface::getModelicaPath()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getModelicaPath("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getModelicaPath(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getModelicaPath failed");)
  
  return result;
}
modelica_boolean OMCInterface::setModelicaPath(QString modelicaPath)
{
  QByteArray modelicaPath_utf8 = modelicaPath.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setModelicaPath("+modelicaPath+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setModelicaPath(threadData, st, mmc_mk_scon(modelicaPath_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setModelicaPath failed");)
  
  return result;
}
QString OMCInterface::getInstallationDirectoryPath()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getInstallationDirectoryPath("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getInstallationDirectoryPath(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getInstallationDirectoryPath failed");)
  
  return result;
}
modelica_boolean OMCInterface::setInstallationDirectoryPath(QString installationDirectoryPath)
{
  QByteArray installationDirectoryPath_utf8 = installationDirectoryPath.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setInstallationDirectoryPath("+installationDirectoryPath+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setInstallationDirectoryPath(threadData, st, mmc_mk_scon(installationDirectoryPath_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setInstallationDirectoryPath failed");)
  
  return result;
}
modelica_boolean OMCInterface::setEnvironmentVar(QString var, QString value)
{
  QByteArray var_utf8 = var.toUtf8();
  QByteArray value_utf8 = value.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setEnvironmentVar("+var+"," +value+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setEnvironmentVar(threadData, st, mmc_mk_scon(var_utf8.data()), mmc_mk_scon(value_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setEnvironmentVar failed");)
  
  return result;
}
QString OMCInterface::getEnvironmentVar(QString var)
{
  QByteArray var_utf8 = var.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getEnvironmentVar("+var+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getEnvironmentVar(threadData, st, mmc_mk_scon(var_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getEnvironmentVar failed");)
  
  return result;
}
QString OMCInterface::getTempDirectoryPath()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getTempDirectoryPath("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getTempDirectoryPath(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getTempDirectoryPath failed");)
  
  return result;
}
modelica_boolean OMCInterface::setTempDirectoryPath(QString tempDirectoryPath)
{
  QByteArray tempDirectoryPath_utf8 = tempDirectoryPath.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setTempDirectoryPath("+tempDirectoryPath+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setTempDirectoryPath(threadData, st, mmc_mk_scon(tempDirectoryPath_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setTempDirectoryPath failed");)
  
  return result;
}
modelica_boolean OMCInterface::setPlotCommand(QString plotCommand)
{
  QByteArray plotCommand_utf8 = plotCommand.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setPlotCommand("+plotCommand+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setPlotCommand(threadData, st, mmc_mk_scon(plotCommand_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setPlotCommand failed");)
  
  return result;
}
modelica_boolean OMCInterface::setCompileCommand(QString compileCommand)
{
  QByteArray compileCommand_utf8 = compileCommand.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setCompileCommand("+compileCommand+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setCompileCommand(threadData, st, mmc_mk_scon(compileCommand_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setCompileCommand failed");)
  
  return result;
}
QString OMCInterface::getCompileCommand()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getCompileCommand("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getCompileCommand(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getCompileCommand failed");)
  
  return result;
}
modelica_boolean OMCInterface::setCompilerPath(QString compilerPath)
{
  QByteArray compilerPath_utf8 = compilerPath.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setCompilerPath("+compilerPath+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setCompilerPath(threadData, st, mmc_mk_scon(compilerPath_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setCompilerPath failed");)
  
  return result;
}
modelica_boolean OMCInterface::verifyCompiler()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("verifyCompiler("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_verifyCompiler(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("verifyCompiler failed");)
  
  return result;
}
modelica_boolean OMCInterface::setCXXCompiler(QString compiler)
{
  QByteArray compiler_utf8 = compiler.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setCXXCompiler("+compiler+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setCXXCompiler(threadData, st, mmc_mk_scon(compiler_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setCXXCompiler failed");)
  
  return result;
}
QString OMCInterface::getCXXCompiler()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getCXXCompiler("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getCXXCompiler(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getCXXCompiler failed");)
  
  return result;
}
QString OMCInterface::getCFlags()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getCFlags("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getCFlags(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getCFlags failed");)
  
  return result;
}
modelica_boolean OMCInterface::setCFlags(QString inString)
{
  QByteArray inString_utf8 = inString.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setCFlags("+inString+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setCFlags(threadData, st, mmc_mk_scon(inString_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setCFlags failed");)
  
  return result;
}
modelica_boolean OMCInterface::setCompiler(QString compiler)
{
  QByteArray compiler_utf8 = compiler.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setCompiler("+compiler+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setCompiler(threadData, st, mmc_mk_scon(compiler_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setCompiler failed");)
  
  return result;
}
QString OMCInterface::getCompiler()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getCompiler("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getCompiler(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getCompiler failed");)
  
  return result;
}
modelica_boolean OMCInterface::setLinkerFlags(QString linkerFlags)
{
  QByteArray linkerFlags_utf8 = linkerFlags.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setLinkerFlags("+linkerFlags+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setLinkerFlags(threadData, st, mmc_mk_scon(linkerFlags_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setLinkerFlags failed");)
  
  return result;
}
QString OMCInterface::getLinkerFlags()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getLinkerFlags("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getLinkerFlags(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getLinkerFlags failed");)
  
  return result;
}
modelica_boolean OMCInterface::setLinker(QString linker)
{
  QByteArray linker_utf8 = linker.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("setLinker("+linker+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_setLinker(threadData, st, mmc_mk_scon(linker_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("setLinker failed");)
  
  return result;
}
QString OMCInterface::getLinker()
{
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("getLinker("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_getLinker(threadData, st, &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("getLinker failed");)
  
  return result;
}
modelica_boolean OMCInterface::generateSeparateCodeDependenciesMakefile(QString filename, QString directory, QString suffix)
{
  QByteArray filename_utf8 = filename.toUtf8();
  QByteArray directory_utf8 = directory.toUtf8();
  QByteArray suffix_utf8 = suffix.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("generateSeparateCodeDependenciesMakefile("+filename+"," +directory+"," +suffix+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_generateSeparateCodeDependenciesMakefile(threadData, st, mmc_mk_scon(filename_utf8.data()), mmc_mk_scon(directory_utf8.data()), mmc_mk_scon(suffix_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("generateSeparateCodeDependenciesMakefile failed");)
  
  return result;
}
QList<QString > OMCInterface::generateSeparateCodeDependencies(QString stampSuffix)
{
  QByteArray stampSuffix_utf8 = stampSuffix.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("generateSeparateCodeDependencies("+stampSuffix+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_generateSeparateCodeDependencies(threadData, st, mmc_mk_scon(stampSuffix_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append("\"" + result_elt + "\"");
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("generateSeparateCodeDependencies failed");)
  
  return result;
}
modelica_boolean OMCInterface::generateSeparateCode(QString className, modelica_boolean cleanCache)
{
  QByteArray className_utf8 = className.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("generateSeparateCode("+className+"," +QString(cleanCache ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_generateSeparateCode(threadData, st, mmc_mk_scon(className_utf8.data()), cleanCache, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("generateSeparateCode failed");)
  
  return result;
}
modelica_boolean OMCInterface::generateHeader(QString fileName)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("generateHeader("+fileName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_generateHeader(threadData, st, mmc_mk_scon(fileName_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("generateHeader failed");)
  
  return result;
}
modelica_boolean OMCInterface::clearVariables()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("clearVariables("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_clearVariables(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("clearVariables failed");)
  
  return result;
}
modelica_boolean OMCInterface::clearProgram()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("clearProgram("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_clearProgram(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("clearProgram failed");)
  
  return result;
}
modelica_boolean OMCInterface::clear()
{
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("clear("+QString("")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_clear(threadData, st, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("clear failed");)
  
  return result;
}
QString OMCInterface::help(QString topic)
{
  QByteArray topic_utf8 = topic.toUtf8();
  QString result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("help("+topic+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_help(threadData, st, mmc_mk_scon(topic_utf8.data()), &result_mm);
  result = QString::fromUtf8(MMC_STRINGDATA(result_mm));
  QString responseLog;
  responseLog.append("\"" + result + "\"");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("help failed");)
  
  return result;
}
modelica_boolean OMCInterface::saveAll(QString fileName)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("saveAll("+fileName+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_saveAll(threadData, st, mmc_mk_scon(fileName_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("saveAll failed");)
  
  return result;
}
QList<modelica_integer > OMCInterface::system_parallel(QList<QString > callStr, modelica_integer numThreads)
{
  void *callStr_lst = mmc_mk_nil();
  for (int callStr_i = callStr.size()-1; callStr_i>=0; callStr_i--) {
    QString callStr_elt = callStr[callStr_i];
    QByteArray callStr_elt_utf8 = callStr_elt.toUtf8();
    callStr_lst = mmc_mk_cons(mmc_mk_scon(callStr_elt_utf8.data()), callStr_lst);
  }
  QList<modelica_integer > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("system__parallel("+QString("### Handle array arguments ###")+"," +QString::number(numThreads)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_system__parallel(threadData, st, callStr_lst, numThreads, &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    modelica_integer result_elt;
    result_elt = mmc_unbox_integer(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(modelica_integer result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(QString::number(result_elt));
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("system__parallel failed");)
  
  return result;
}
modelica_integer OMCInterface::system(QString callStr, QString outputFile)
{
  QByteArray callStr_utf8 = callStr.toUtf8();
  QByteArray outputFile_utf8 = outputFile.toUtf8();
  modelica_integer result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("system("+callStr+"," +outputFile+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_system(threadData, st, mmc_mk_scon(callStr_utf8.data()), mmc_mk_scon(outputFile_utf8.data()), &result);
  QString responseLog;
  responseLog.append(QString::number(result));
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("system failed");)
  
  return result;
}
QList<QString > OMCInterface::loadFileInteractive(QString filename, QString encoding)
{
  QByteArray filename_utf8 = filename.toUtf8();
  QByteArray encoding_utf8 = encoding.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("loadFileInteractive("+filename+"," +encoding+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_loadFileInteractive(threadData, st, mmc_mk_scon(filename_utf8.data()), mmc_mk_scon(encoding_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(result_elt);
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("loadFileInteractive failed");)
  
  return result;
}
QList<QString > OMCInterface::loadFileInteractiveQualified(QString filename, QString encoding)
{
  QByteArray filename_utf8 = filename.toUtf8();
  QByteArray encoding_utf8 = encoding.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("loadFileInteractiveQualified("+filename+"," +encoding+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_loadFileInteractiveQualified(threadData, st, mmc_mk_scon(filename_utf8.data()), mmc_mk_scon(encoding_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(result_elt);
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("loadFileInteractiveQualified failed");)
  
  return result;
}
QList<QString > OMCInterface::parseFile(QString filename, QString encoding)
{
  QByteArray filename_utf8 = filename.toUtf8();
  QByteArray encoding_utf8 = encoding.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("parseFile("+filename+"," +encoding+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_parseFile(threadData, st, mmc_mk_scon(filename_utf8.data()), mmc_mk_scon(encoding_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(result_elt);
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("parseFile failed");)
  
  return result;
}
QList<QString > OMCInterface::parseString(QString data, QString filename)
{
  QByteArray data_utf8 = data.toUtf8();
  QByteArray filename_utf8 = filename.toUtf8();
  QList<QString > result;
  void *result_mm = NULL;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("parseString("+data+"," +filename+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_parseString(threadData, st, mmc_mk_scon(data_utf8.data()), mmc_mk_scon(filename_utf8.data()), &result_mm);
  result.clear();
  while (!listEmpty(result_mm)) {
    QString result_elt;
    result_elt = MMC_STRINGDATA(MMC_CAR(result_mm));
    result.push_back(result_elt);
    result_mm = MMC_CDR(result_mm);
  }
  QString responseLog;
  responseLog.append("{");
  int result_i = 0;
  foreach(QString result_elt, result) {
    if (result_i) {
      responseLog.append(",");
    }
    responseLog.append(result_elt);
    result_i++;
  }
  responseLog.append("}");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("parseString failed");)
  
  return result;
}
modelica_boolean OMCInterface::loadString(QString data, QString filename, QString encoding)
{
  QByteArray data_utf8 = data.toUtf8();
  QByteArray filename_utf8 = filename.toUtf8();
  QByteArray encoding_utf8 = encoding.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("loadString("+data+"," +filename+"," +encoding+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_loadString(threadData, st, mmc_mk_scon(data_utf8.data()), mmc_mk_scon(filename_utf8.data()), mmc_mk_scon(encoding_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("loadString failed");)
  
  return result;
}
modelica_boolean OMCInterface::reloadClass(QString name, QString encoding)
{
  QByteArray name_utf8 = name.toUtf8();
  QByteArray encoding_utf8 = encoding.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("reloadClass("+name+"," +encoding+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_reloadClass(threadData, st, mmc_mk_scon(name_utf8.data()), mmc_mk_scon(encoding_utf8.data()), &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("reloadClass failed");)
  
  return result;
}
modelica_boolean OMCInterface::loadFiles(QList<QString > fileNames, QString encoding, modelica_integer numThreads)
{
  void *fileNames_lst = mmc_mk_nil();
  for (int fileNames_i = fileNames.size()-1; fileNames_i>=0; fileNames_i--) {
    QString fileNames_elt = fileNames[fileNames_i];
    QByteArray fileNames_elt_utf8 = fileNames_elt.toUtf8();
    fileNames_lst = mmc_mk_cons(mmc_mk_scon(fileNames_elt_utf8.data()), fileNames_lst);
  }
  QByteArray encoding_utf8 = encoding.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("loadFiles("+QString("### Handle array arguments ###")+"," +encoding+"," +QString::number(numThreads)+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_loadFiles(threadData, st, fileNames_lst, mmc_mk_scon(encoding_utf8.data()), numThreads, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("loadFiles failed");)
  
  return result;
}
modelica_boolean OMCInterface::loadFile(QString fileName, QString encoding, modelica_boolean uses)
{
  QByteArray fileName_utf8 = fileName.toUtf8();
  QByteArray encoding_utf8 = encoding.toUtf8();
  modelica_boolean result;
  
  MMC_TRY_TOP_INTERNAL()
  
  QTime commandTime;
  commandTime.start();
  emit logCommand("loadFile("+fileName+"," +encoding+"," +QString(uses ? "true" : "false")+")", &commandTime);
  st = omc_OpenModelicaScriptingAPI_loadFile(threadData, st, mmc_mk_scon(fileName_utf8.data()), mmc_mk_scon(encoding_utf8.data()), uses, &result);
  QString responseLog;
  responseLog.append(result ? "true" : "false");
  emit logResponse(responseLog, &commandTime);
  
  MMC_CATCH_TOP(throw std::runtime_error("loadFile failed");)
  
  return result;
}
